# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vellum_video import VellumVideo


class NodeInputCompiledVideoValue(UniversalBaseModel):
    node_input_id: str
    key: str
    type: typing.Literal["VIDEO"] = "VIDEO"
    value: typing.Optional[VellumVideo] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
