# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .document_index_chunking import DocumentIndexChunking
from .indexing_config_vectorizer import IndexingConfigVectorizer


class DocumentIndexIndexingConfig(UniversalBaseModel):
    vectorizer: IndexingConfigVectorizer
    chunking: typing.Optional[DocumentIndexChunking] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
